@@ -94,9 +94,6 @@
 #include <QWhatsThis>
 #include <QDomDocument>
 
-// trailing slash is important
-#define HLDOWNLOADPATH QStringLiteral("http://kate.kde.org/syntax/")
-
 //END
 
 //BEGIN KateIndentConfigTab
@@ -391,6 +388,7 @@ KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
     connect(ui->chkPagingMovesCursor, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(ui->sbAutoCenterCursor, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
     connect(ui->chkScrollPastEnd, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(ui->chkBackspaceRemoveComposed, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
     layout->addWidget(newWidget);
     setLayout(layout);
@@ -421,6 +419,8 @@ void KateNavigationConfigTab::apply()
 
     KateViewConfig::global()->setScrollPastEnd(ui->chkScrollPastEnd->isChecked());
 
+    KateViewConfig::global()->setBackspaceRemoveComposed(ui->chkBackspaceRemoveComposed->isChecked());
+
     KateDocumentConfig::global()->configEnd();
     KateViewConfig::global()->configEnd();
 }
@@ -433,6 +433,7 @@ void KateNavigationConfigTab::reload()
     ui->chkPagingMovesCursor->setChecked(KateDocumentConfig::global()->pageUpDownMovesCursor());
     ui->sbAutoCenterCursor->setValue(KateViewConfig::global()->autoCenterLines());
     ui->chkScrollPastEnd->setChecked(KateViewConfig::global()->scrollPastEnd());
+    ui->chkBackspaceRemoveComposed->setChecked(KateViewConfig::global()->backspaceRemoveComposed());
 }
 
 QString KateNavigationConfigTab::name() const
@@ -670,9 +671,12 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     connect(textareaUi->chkShowTabs, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(textareaUi->chkShowSpaces, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(textareaUi->chkShowIndentationLines, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(textareaUi->sliSetMarkerSize, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
     connect(textareaUi->chkShowWholeBracketExpression, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(textareaUi->chkAnimateBracketMatching, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(textareaUi->chkFoldFirstLine,  SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(textareaUi->chkShowWordCount,  SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+    connect(textareaUi->chkShowLineCount, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
     connect(bordersUi->chkIconBorder, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
     connect(bordersUi->chkScrollbarMarks, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
@@ -712,6 +716,7 @@ void KateViewDefaultsConfig::apply()
     KateViewConfig::global()->setDynWordWrapAlignIndent(textareaUi->sbDynamicWordWrapDepth->value());
     KateDocumentConfig::global()->setShowTabs(textareaUi->chkShowTabs->isChecked());
     KateDocumentConfig::global()->setShowSpaces(textareaUi->chkShowSpaces->isChecked());
+    KateDocumentConfig::global()->setMarkerSize(textareaUi->sliSetMarkerSize->value());
     KateViewConfig::global()->setLineNumbers(bordersUi->chkLineNumbers->isChecked());
     KateViewConfig::global()->setIconBar(bordersUi->chkIconBorder->isChecked());
     KateViewConfig::global()->setScrollBarMarks(bordersUi->chkScrollbarMarks->isChecked());
@@ -729,6 +734,8 @@ void KateViewDefaultsConfig::apply()
     KateRendererConfig::global()->setShowWholeBracketExpression(textareaUi->chkShowWholeBracketExpression->isChecked());
     KateRendererConfig::global()->setAnimateBracketMatching(textareaUi->chkAnimateBracketMatching->isChecked());
     KateViewConfig::global()->setFoldFirstLine(textareaUi->chkFoldFirstLine->isChecked());
+    KateViewConfig::global()->setShowWordCount(textareaUi->chkShowWordCount->isChecked());
+    KateViewConfig::global()->setShowLineCount(textareaUi->chkShowLineCount->isChecked());
 
     KateRendererConfig::global()->configEnd();
     KateViewConfig::global()->configEnd();
@@ -741,6 +748,7 @@ void KateViewDefaultsConfig::reload()
     textareaUi->sbDynamicWordWrapDepth->setValue(KateViewConfig::global()->dynWordWrapAlignIndent());
     textareaUi->chkShowTabs->setChecked(KateDocumentConfig::global()->showTabs());
     textareaUi->chkShowSpaces->setChecked(KateDocumentConfig::global()->showSpaces());
+    textareaUi->sliSetMarkerSize->setValue(KateDocumentConfig::global()->markerSize());
     bordersUi->chkLineNumbers->setChecked(KateViewConfig::global()->lineNumbers());
     bordersUi->chkIconBorder->setChecked(KateViewConfig::global()->iconBar());
     bordersUi->chkScrollbarMarks->setChecked(KateViewConfig::global()->scrollBarMarks());
@@ -758,6 +766,8 @@ void KateViewDefaultsConfig::reload()
     textareaUi->chkShowWholeBracketExpression->setChecked(KateRendererConfig::global()->showWholeBracketExpression());
     textareaUi->chkAnimateBracketMatching->setChecked(KateRendererConfig::global()->animateBracketMatching());
     textareaUi->chkFoldFirstLine->setChecked(KateViewConfig::global()->foldFirstLine());
+    textareaUi->chkShowWordCount->setChecked(KateViewConfig::global()->showWordCount());
+    textareaUi->chkShowLineCount->setChecked(KateViewConfig::global()->showLineCount());
 }
 
 void KateViewDefaultsConfig::reset()
@@ -1043,172 +1053,6 @@ QIcon KateSaveConfigTab::icon() const
 
 //END KateSaveConfigTab
 
-//BEGIN KateHlDownloadDialog
-KateHlDownloadDialog::KateHlDownloadDialog(QWidget *parent, const char *name, bool modal)
-    : QDialog(parent)
-{
-    setWindowTitle(i18n("Highlight Download"));
-    setObjectName(QString::fromUtf8(name));
-    setModal(modal);
-
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
-
-    QLabel *label = new QLabel(i18n("Select the syntax highlighting files you want to update:"), this);
-    mainLayout->addWidget(label);
-
-    list = new QTreeWidget(this);
-    list->setColumnCount(4);
-    list->setHeaderLabels(QStringList() << QString() << i18n("Name") << i18n("Installed") << i18n("Latest"));
-    list->setSelectionMode(QAbstractItemView::MultiSelection);
-    list->setAllColumnsShowFocus(true);
-    list->setRootIsDecorated(false);
-    list->setColumnWidth(0, 22);
-    mainLayout->addWidget(list);
-
-    label = new QLabel(i18n("<b>Note:</b> New versions are selected automatically."), this);
-    mainLayout->addWidget(label);
-
-    // buttons
-    QDialogButtonBox *buttons = new QDialogButtonBox(this);
-    mainLayout->addWidget(buttons);
-
-    m_installButton = new QPushButton(QIcon::fromTheme(QStringLiteral("dialog-ok")), i18n("&Install"));
-    m_installButton->setDefault(true);
-    buttons->addButton(m_installButton, QDialogButtonBox::AcceptRole);
-    connect(m_installButton, SIGNAL(clicked()), this, SLOT(slotInstall()));
-
-    QPushButton *closeButton = new QPushButton;
-    KGuiItem::assign(closeButton, KStandardGuiItem::cancel());
-    buttons->addButton(closeButton, QDialogButtonBox::RejectRole);
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(reject()));
-
-    transferJob = KIO::get(QUrl(QStringLiteral("%1update-%2.%3.xml").arg(HLDOWNLOADPATH).arg(KTEXTEDITOR_VERSION_MAJOR).arg(KTEXTEDITOR_VERSION_MINOR)), KIO::Reload);
-    connect(transferJob, SIGNAL(data(KIO::Job*,QByteArray)),
-            this, SLOT(listDataReceived(KIO::Job*,QByteArray)));
-//        void data( KIO::Job *, const QByteArray &data);
-
-    resize(450, 400);
-}
-
-KateHlDownloadDialog::~KateHlDownloadDialog() {}
-
-/// Split typical version string (\c major.minor.patch) into
-/// numeric components, convert 'em to \c unsigned and form a
-/// single value that can be compared w/ other versions
-/// using relation operators.
-/// \note It takes into account only first 3 numbers
-unsigned KateHlDownloadDialog::parseVersion(const QString &version_string)
-{
-    unsigned vn[3] = {0, 0, 0};
-    unsigned idx = 0;
-    foreach (const QString &n, version_string.split(QLatin1Char('.'))) {
-        vn[idx++] = n.toUInt();
-        if (idx == sizeof(vn)) {
-            break;
-        }
-    }
-    return (((vn[0]) << 16) | ((vn[1]) << 8) | (vn[2]));
-}
-
-void KateHlDownloadDialog::listDataReceived(KIO::Job *, const QByteArray &data)
-{
-    if (!transferJob || transferJob->isErrorPage()) {
-        m_installButton->setEnabled(false);
-        if (data.size() == 0) {
-            KMessageBox::error(this, i18n("The list of highlightings could not be found on / retrieved from the server"));
-        }
-        return;
-    }
-
-    listData += QLatin1String(data);
-    qCDebug(LOG_KTE) << QStringLiteral("CurrentListData: ") << listData;
-    qCDebug(LOG_KTE) << QStringLiteral("Data length: %1").arg(data.size());
-    qCDebug(LOG_KTE) << QStringLiteral("listData length: %1").arg(listData.length());
-    if (data.size() == 0) {
-        if (listData.length() > 0) {
-            QString installedVersion;
-            KateHlManager *hlm = KateHlManager::self();
-            QDomDocument doc;
-            doc.setContent(listData);
-            QDomElement DocElem = doc.documentElement();
-            QDomNode n = DocElem.firstChild();
-            KateHighlighting *hl = nullptr;
-
-            if (n.isNull()) {
-                qCDebug(LOG_KTE) << QStringLiteral("There is no usable childnode");
-            }
-            while (!n.isNull()) {
-                installedVersion = QStringLiteral("    --");
-
-                QDomElement e = n.toElement();
-                if (!e.isNull()) {
-                    qCDebug(LOG_KTE) << QStringLiteral("NAME: ") << e.tagName() << QStringLiteral(" - ") << e.attribute(QStringLiteral("name"));
-                }
-                n = n.nextSibling();
-
-                QString Name = e.attribute(QStringLiteral("name"));
-
-                for (int i = 0; i < hlm->highlights(); i++) {
-                    hl = hlm->getHl(i);
-                    if (hl && hl->name() == Name) {
-                        installedVersion = QLatin1String("    ") + hl->version();
-                        break;
-                    } else {
-                        hl = nullptr;
-                    }
-                }
-
-                // autoselect entry if new or updated.
-                QTreeWidgetItem *entry = new QTreeWidgetItem(list);
-                entry->setText(0, QString());
-                entry->setText(1, e.attribute(QStringLiteral("name")));
-                entry->setText(2, installedVersion);
-                entry->setText(3, e.attribute(QStringLiteral("version")));
-                entry->setText(4, e.attribute(QStringLiteral("url")));
-
-                bool is_fresh = false;
-                if (hl) {
-                    unsigned prev_version = parseVersion(hl->version());
-                    unsigned next_version = parseVersion(e.attribute(QStringLiteral("version")));
-                    is_fresh = prev_version < next_version;
-                } else {
-                    is_fresh = true;
-                }
-                if (is_fresh) {
-                    entry->treeWidget()->setItemSelected(entry, true);
-                    entry->setIcon(0, QIcon::fromTheme((QStringLiteral("get-hot-new-stuff"))));
-                }
-            }
-            list->resizeColumnToContents(1);
-            list->sortItems(1, Qt::AscendingOrder);
-        }
-    }
-}
-
-void KateHlDownloadDialog::slotInstall()
-{
-    const QString destdir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/org.kde.syntax-highlighting/syntax/");
-    QDir(destdir).mkpath(QStringLiteral(".")); // make sure the dir is there
-
-    foreach (QTreeWidgetItem *it, list->selectedItems()) {
-        QUrl src(it->text(4));
-        QString filename = src.fileName();
-
-        // if there is no fileName construct at least something
-        if (filename.isEmpty()) {
-            filename = src.path().replace(QLatin1Char('/'), QLatin1Char('_'));
-        }
-
-        QUrl dest = QUrl::fromLocalFile(destdir + filename);
-
-        KIO::FileCopyJob *job = KIO::file_copy(src, dest);
-        KJobWidgets::setWindow(job, this);
-        job->exec();
-    }
-}
-//END KateHlDownloadDialog
-
 //BEGIN KateGotoBar
 KateGotoBar::KateGotoBar(KTextEditor::View *view, QWidget *parent)
     : KateViewBarWidget(true, parent)
@@ -1452,7 +1296,7 @@ void KateModOnHdPrompt::slotPDone()
     m_diffFile = nullptr;
 
     // KRun::runUrl should delete the file, once the client exits
-    KRun::runUrl(url, QStringLiteral("text/x-patch"), nullptr, true);
+    KRun::runUrl(url, QStringLiteral("text/x-patch"), nullptr, KRun::RunFlags(KRun::DeleteTemporaryFiles));
 }
 
 //END KateModOnHdPrompt
