@@ -1,5 +1,5 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2012 Dominik Haumann <dhaumann kde org>
+   Copyright (C) 2012-2018 Dominik Haumann <dhaumann@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -39,7 +39,7 @@
 class KateColorTreeItem : public QTreeWidgetItem
 {
 public:
-    KateColorTreeItem(const KateColorItem &colorItem, QTreeWidgetItem *parent = 0)
+    KateColorTreeItem(const KateColorItem &colorItem, QTreeWidgetItem *parent = nullptr)
         : QTreeWidgetItem(parent)
         , m_colorItem(colorItem)
     {
@@ -104,7 +104,7 @@ public:
     {
     }
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         QSize sh = QStyledItemDelegate::sizeHint(option, index);
         if (!index.parent().isValid()) {
@@ -149,7 +149,7 @@ public:
         return r;
     }
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         Q_ASSERT(index.isValid());
         Q_ASSERT(index.column() >= 0 && index.column() <= 2);
@@ -209,7 +209,7 @@ public:
             opt.rect.adjust(1, 1, -1, -1);
             painter->fillRect(opt.rect, color);
 
-            qDrawShadePanel(painter, opt.rect, opt.palette, true, 1, NULL);
+            qDrawShadePanel(painter, opt.rect, opt.palette, true, 1, nullptr);
         }
         //END: draw color button
 
@@ -325,7 +325,7 @@ void KateColorTreeWidget::selectDefaults()
 
 void KateColorTreeWidget::addColorItem(const KateColorItem &colorItem)
 {
-    QTreeWidgetItem *categoryItem = 0;
+    QTreeWidgetItem *categoryItem = nullptr;
     for (int i = 0; i < topLevelItemCount(); ++i) {
         if (topLevelItem(i)->text(0) == colorItem.category) {
             categoryItem = topLevelItem(i);
